const path = require("path");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const fs = require('fs')
const ESLintPlugin = require("eslint-webpack-plugin");

const plugins = [new HtmlWebpackPlugin({
	template: "src/index.html",
	favicon: "src/image/favicon.ico"
})];

if (fs.existsSync('../../.eslintrc.js'))
{
	plugins.push(new ESLintPlugin({
			extensions: [".ts"],
			emitWarning: true,
			emitError: true,
			failOnWarning: true,
		})
	);
}

module.exports = {
	entry: "./src/index",
	module: {
		rules: [
			{
				test: /\.tsx?$/,
				use: "ts-loader",
				exclude: /node_modules/
			},
			{
				// Pack images (e.g. when importing a dependency's css)
				test: /\.(jpe?g|png|gif|svg|ico)$/,
				type: "asset/resource",
				use: "image-webpack-loader"
			},
			{
				// SCSS: Compile to CSS, inject CSS in index.html (style-loader)
				test: /\.scss$/,
				use: [
					"style-loader",
					{loader: "css-loader", options: {sourceMap: true, esModule: false}},
					{loader: "resolve-url-loader", options: {sourceMap: true}},
					{loader: "sass-loader", options: {sourceMap: true}},
				]
			}
		]
	},
	resolve: {
		extensions: [".ts", ".js"]
	},
	plugins,
	output: {
		filename: "bundle.js",
		path: path.resolve(__dirname, "dist")
	},
	devtool: "inline-source-map",
	devServer: {
		static: path.resolve(__dirname, "dist"),
	},
	mode: "development"
};
